==> mingw-w64-notepad%2B%2B-8.7-1.src.tar.zst: notepad-plus-plus-8.7/PowerEditor/src/ScintillaComponent/FindReplaceDlg_rc.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#ifndef FINDREPLACE_DLG_H
#define FINDREPLACE_DLG_H

#define	IDD_FIND_REPLACE_DLG			1600
#define	IDFINDWHAT						1601
#define	IDREPLACEWITH					1602
#define	IDWHOLEWORD						1603
#define IDF_WHOLEWORD	1
#define	IDMATCHCASE						1604
#define IDF_MATCHCASE	2

#define IDREGEXP						1605

#define	IDWRAP							1606
#define	IDF_WRAP	256
#define	IDUNSLASH						1607
#define	IDREPLACE						1608
#define	IDREPLACEALL					1609
#define	IDD_FINDREPLACE_SWAP_BUTTON		1610
#define	ID_STATICTEXT_REPLACE			1611
//#define	IDDIRECTIONUP					1612
//#define	IDDIRECTIONDOWN 				1613
#define IDF_WHICH_DIRECTION	512
#define	IDCCOUNTALL						1614
#define	IDCMARKALL						1615
#define	IDC_MARKLINE_CHECK				1616
#define IDF_MARKLINE_CHECK	16
//#define	IDC_STYLEFOUND_CHECK			1617
#define IDF_STYLEFOUND_CHECK	8
#define	IDC_PURGE_CHECK					1618
#define IDF_PURGE_CHECK	4
#define	IDC_FINDALL_STATIC				1619
#define	IDFINDWHAT_STATIC				1620
//#define	IDC_DIR_STATIC					1621

#define	IDC_PERCENTAGE_SLIDER			1622
#define	IDC_TRANSPARENT_GRPBOX 			1623

#define IDC_MODE_STATIC					1624
#define IDNORMAL						1625
#define IDEXTENDED						1626

#define	IDC_FIND_IN_STATIC				1628
//#define	IDC_CURRENT_FILE_RADIO		1629
//#define	IDC_OPENED_FILES_RADIO		1630
//#define	IDC_FILES_RADIO				1631
#define	IDC_IN_SELECTION_CHECK   		1632
#define	IDF_IN_SELECTION_CHECK	128
#define	IDC_CLEAR_ALL            		1633
#define	IDC_REPLACEINSELECTION   		1634
#define	IDC_REPLACE_OPENEDFILES  		1635
#define	IDC_FINDALL_OPENEDFILES  		1636
//#define	IDC_FINDINFILES  1637
#define	IDC_FINDINFILES_LAUNCH			1638
#define	IDC_GETCURRENTDOCTYPE			1639
#define	IDD_RESIZE_TOGGLE_BUTTON		1640
#define	IDC_FINDALL_CURRENTFILE			1641

#define	IDD_FINDINFILES_DLG				1650
#define	IDD_FINDINFILES_BROWSE_BUTTON	1651
#define	IDD_FINDINFILES_FILTERS_COMBO	1652
#define	IDD_FINDINFILES_DIR_COMBO		1653
#define	IDD_FINDINFILES_FILTERS_STATIC	1654
#define	IDD_FINDINFILES_DIR_STATIC		1655
#define	IDD_FINDINFILES_FIND_BUTTON		1656
#define	IDD_FINDINFILES_RECURSIVE_CHECK		1658
#define IDF_FINDINFILES_RECURSIVE_CHECK	32
#define	IDD_FINDINFILES_INHIDDENDIR_CHECK	1659
#define	IDF_FINDINFILES_INHIDDENDIR_CHECK	64
#define	IDD_FINDINFILES_REPLACEINFILES	1660
#define	IDD_FINDINFILES_FOLDERFOLLOWSDOC_CHECK	1661
#define IDD_FINDINFILES_PROJECT1_CHECK	1662
#define IDF_FINDINFILES_PROJECT1_CHECK	128
#define IDD_FINDINFILES_PROJECT2_CHECK	1663
#define IDF_FINDINFILES_PROJECT2_CHECK	256
#define IDD_FINDINFILES_PROJECT3_CHECK	1664
#define IDF_FINDINFILES_PROJECT3_CHECK	512
#define	IDD_FINDINFILES_REPLACEINPROJECTS	1665
#define	IDD_FINDINFILES_FINDINPROJECTS	1666

#define	IDD_FINDRESULT					1670

#define	IDD_INCREMENT_FIND				1680
#define	IDC_INCSTATIC					1681
#define	IDC_INCFINDTEXT					1682
#define	IDC_INCFINDPREVOK				1683
#define	IDC_INCFINDNXTOK				1684
#define	IDC_INCFINDMATCHCASE			1685
#define	IDC_TRANSPARENT_CHECK				1686
#define	IDC_TRANSPARENT_LOSSFOCUS_RADIO		1687
#define	IDC_TRANSPARENT_ALWAYS_RADIO		1688
#define IDC_INCFINDSTATUS				1689
#define	IDC_INCFINDHILITEALL			1690

#define	IDB_INCREMENTAL_BG				1691


#define IDC_FRCOMMAND_INIT				1700
#define IDC_FRCOMMAND_EXEC				1701
#define IDC_FRCOMMAND_BOOLEANS			1702

#define IDREDOTMATCHNL					1703
#define IDF_REDOTMATCHNL	1024

#define	IDD_FINDINFINDER_DLG			1710
#define	IDFINDWHAT_STATIC_FIFOLDER		1711
#define	IDFINDWHAT_FIFOLDER				1712
#define	IDC_MATCHLINENUM_CHECK_FIFOLDER 1713
#define	IDWHOLEWORD_FIFOLDER			1714
#define	IDMATCHCASE_FIFOLDER			1715
#define IDC_MODE_STATIC_FIFOLDER		1716
#define IDNORMAL_FIFOLDER				1717
#define IDEXTENDED_FIFOLDER				1718
#define IDREGEXP_FIFOLDER				1719
#define IDREDOTMATCHNL_FIFOLDER			1720
#define IDC_FINDPREV					1721
#define IDC_BACKWARDDIRECTION			1722
#define IDC_FINDNEXT					1723
#define IDC_2_BUTTONS_MODE				1724

#define IDC_COPY_MARKED_TEXT			1725

#define IDC_SWAP_FIND_REPLACE			1726
#define IDC_COPY_FIND2REPLACE			1727
#define IDC_COPY_REPLACE2FIND			1728

#endif //FINDREPLACE_DLG_H

==> mingw-w64-notepad%2B%2B-8.7.5-1.src.tar.zst: notepad-plus-plus-8.7.5/PowerEditor/src/ScintillaComponent/FindReplaceDlg_rc.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#ifndef FINDREPLACE_DLG_H
#define FINDREPLACE_DLG_H

#define	IDD_FIND_REPLACE_DLG			1600
#define	IDFINDWHAT						1601
#define	IDREPLACEWITH					1602
#define	IDWHOLEWORD						1603
#define IDF_WHOLEWORD	1
#define	IDMATCHCASE						1604
#define IDF_MATCHCASE	2

#define IDREGEXP						1605

#define	IDWRAP							1606
#define	IDF_WRAP	256
#define	IDUNSLASH						1607
#define	IDREPLACE						1608
#define	IDREPLACEALL					1609
#define	IDD_FINDREPLACE_SWAP_BUTTON		1610
#define	ID_STATICTEXT_REPLACE			1611
//#define	IDDIRECTIONUP					1612
//#define	IDDIRECTIONDOWN 				1613
#define IDF_WHICH_DIRECTION	512
#define	IDCCOUNTALL						1614
#define	IDCMARKALL						1615
#define	IDC_MARKLINE_CHECK				1616
#define IDF_MARKLINE_CHECK	16
//#define	IDC_STYLEFOUND_CHECK			1617
#define IDF_STYLEFOUND_CHECK	8
#define	IDC_PURGE_CHECK					1618
#define IDF_PURGE_CHECK	4
#define	IDC_FINDALL_STATIC				1619
#define	IDFINDWHAT_STATIC				1620
//#define	IDC_DIR_STATIC					1621

#define	IDC_PERCENTAGE_SLIDER			1622
#define	IDC_TRANSPARENT_GRPBOX 			1623

#define IDC_MODE_STATIC					1624
#define IDNORMAL						1625
#define IDEXTENDED						1626

#define	IDC_FIND_IN_STATIC				1628
//#define	IDC_CURRENT_FILE_RADIO		1629
//#define	IDC_OPENED_FILES_RADIO		1630
//#define	IDC_FILES_RADIO				1631
#define	IDC_IN_SELECTION_CHECK   		1632
#define	IDF_IN_SELECTION_CHECK	128
#define	IDC_CLEAR_ALL            		1633
#define	IDC_REPLACEINSELECTION   		1634
#define	IDC_REPLACE_OPENEDFILES  		1635
#define	IDC_FINDALL_OPENEDFILES  		1636
//#define	IDC_FINDINFILES  1637
#define	IDC_FINDINFILES_LAUNCH			1638
#define	IDC_GETCURRENTDOCTYPE			1639
#define	IDD_RESIZE_TOGGLE_BUTTON		1640
#define	IDC_FINDALL_CURRENTFILE			1641

#define	IDD_FINDINFILES_DLG				1650
#define	IDD_FINDINFILES_BROWSE_BUTTON	1651
#define	IDD_FINDINFILES_FILTERS_COMBO	1652
#define	IDD_FINDINFILES_DIR_COMBO		1653
#define	IDD_FINDINFILES_FILTERS_STATIC	1654
#define	IDD_FINDINFILES_DIR_STATIC		1655
#define	IDD_FINDINFILES_FIND_BUTTON		1656
#define	IDD_FINDINFILES_RECURSIVE_CHECK		1658
#define IDF_FINDINFILES_RECURSIVE_CHECK	32
#define	IDD_FINDINFILES_INHIDDENDIR_CHECK	1659
#define	IDF_FINDINFILES_INHIDDENDIR_CHECK	64
#define	IDD_FINDINFILES_REPLACEINFILES	1660
#define	IDD_FINDINFILES_SETDIRFROMDOC_BUTTON	1661
#define IDD_FINDINFILES_PROJECT1_CHECK	1662
#define IDF_FINDINFILES_PROJECT1_CHECK	128
#define IDD_FINDINFILES_PROJECT2_CHECK	1663
#define IDF_FINDINFILES_PROJECT2_CHECK	256
#define IDD_FINDINFILES_PROJECT3_CHECK	1664
#define IDF_FINDINFILES_PROJECT3_CHECK	512
#define	IDD_FINDINFILES_REPLACEINPROJECTS	1665
#define	IDD_FINDINFILES_FINDINPROJECTS	1666

#define	IDD_FINDRESULT					1670

#define	IDD_INCREMENT_FIND				1680
#define	IDC_INCSTATIC					1681
#define	IDC_INCFINDTEXT					1682
#define	IDC_INCFINDPREVOK				1683
#define	IDC_INCFINDNXTOK				1684
#define	IDC_INCFINDMATCHCASE			1685
#define	IDC_TRANSPARENT_CHECK				1686
#define	IDC_TRANSPARENT_LOSSFOCUS_RADIO		1687
#define	IDC_TRANSPARENT_ALWAYS_RADIO		1688
#define IDC_INCFINDSTATUS				1689
#define	IDC_INCFINDHILITEALL			1690

#define	IDB_INCREMENTAL_BG				1691


#define IDC_FRCOMMAND_INIT				1700
#define IDC_FRCOMMAND_EXEC				1701
#define IDC_FRCOMMAND_BOOLEANS			1702

#define IDREDOTMATCHNL					1703
#define IDF_REDOTMATCHNL	1024

#define	IDD_FINDINFINDER_DLG			1710
#define	IDFINDWHAT_STATIC_FIFOLDER		1711
#define	IDFINDWHAT_FIFOLDER				1712
#define	IDC_MATCHLINENUM_CHECK_FIFOLDER 1713
#define	IDWHOLEWORD_FIFOLDER			1714
#define	IDMATCHCASE_FIFOLDER			1715
#define IDC_MODE_STATIC_FIFOLDER		1716
#define IDNORMAL_FIFOLDER				1717
#define IDEXTENDED_FIFOLDER				1718
#define IDREGEXP_FIFOLDER				1719
#define IDREDOTMATCHNL_FIFOLDER			1720
#define IDC_FINDPREV					1721
#define IDC_BACKWARDDIRECTION			1722
#define IDC_FINDNEXT					1723
#define IDC_2_BUTTONS_MODE				1724

#define IDC_COPY_MARKED_TEXT			1725

#define IDC_SWAP_FIND_REPLACE			1726
#define IDC_COPY_FIND2REPLACE			1727
#define IDC_COPY_REPLACE2FIND			1728

#endif //FINDREPLACE_DLG_H
